# -*- coding: utf-8 -*-

"""Main module."""

import os

import django
from django.conf import settings as django_settings
from django.core.exceptions import ImproperlyConfigured
from django.core.management import call_command

# TODO I believe this can be removed
os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")


def configure(settings=None, command=None, run_migrations=False):
    """
      settings is a dictionary of UPPERCASE Django settings.

      command is a string that represents a Django management command.
          Example:
              migrate
              makemigrations myapp
    """
    if settings is None:
        try:
            INSTALLED_APPS = os.environ['DJANGO_INSTALLED_APPS'].split(',')
        except KeyError:
            raise ImproperlyConfigured("DJANGO_INSTALLED_APPS must be set.")

        settings = dict(
            DATABASES={
                "default": {"ENGINE": "django.db.backends.sqlite3", "NAME": ":memory:"}
            },
            INSTALLED_APPS=INSTALLED_APPS,
            ROOT_URLCONF="",  # tests override urlconf, but it still needs to be defined
            MIDDLEWARE_CLASSES=()
        )

    # Configure environment
    try:
        django_settings.configure(**settings)
        # TODO I believe this can be removed
        django.setup()
    except RuntimeError:
        pass

    if command is not None:
        call_command(*command.split(' '))

    if command is None and run_migrations is True:
        call_command(*['migrate', ])


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

import sys, os
from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.md') as history_file:
    history = history_file.read()

version = '0.1.7'    

if sys.argv[-1] == "publish":
    os.system("rm -rf dist")
    os.system("python setup.py sdist bdist_wheel")
    os.system("twine upload dist/*")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()    

requirements = []

setup_requirements = []

test_requirements = [ ]

setup(
    author="Daniel Roy Greenfeld",
    author_email='pydanny@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="A package for configuring Django in non-traditional environments.",
    install_requires=requirements,
    license="Apache Software License 2.0",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords='configure_django',
    name='configure_django',
    packages=find_packages(include=['configure_django']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/pydanny/configure_django',
    version=version,
    zip_safe=False,
)



# -*- coding: utf-8 -*-

"""Top-level package for configure-django."""

__author__ = """Daniel Roy Greenfeld"""
__email__ = 'pydanny@gmail.com'
__version__ = '0.1.7'

from .configure_django import configure